Module: Ukiryu::Stream

Defined in:
lib/ukiryu/io.rb

Overview

Standard stream constants

Constant Summary collapse

STDIN =

Standard input stream descriptor

Used for commands that can read from stdin instead of a file

Examples:

# Read from stdin
tool.options_for(:process).tap do |opts|
  opts.inputs = [Ukiryu::IO::Stream::STDIN]
  opts.output = "output.pdf"
end
:stdin
STDOUT =

Standard output stream descriptor

Used for commands that can write to stdout instead of a file

Examples:

tool.options_for(:export).tap do |opts|
  opts.inputs = ["input.svg"]
  opts.output = Ukiryu::IO::Stream::STDOUT
end
:stdout
STDERR =

Standard error stream descriptor

Used for separating stderr from stdout

:stderr