Class: Ukiryu::Models::CommandInfo
- Inherits:
-
Lutaml::Model::Serializable
- Object
- Lutaml::Model::Serializable
- Ukiryu::Models::CommandInfo
- Defined in:
- lib/ukiryu/models/command_info.rb
Overview
Command execution information
Contains details about the executed command including the executable path, structured arguments, full command string, and shell used.