Module: Ukiryu::Stream
- Defined in:
- lib/ukiryu/io.rb
Overview
Standard stream constants
Constant Summary collapse
- STDIN =
Standard input stream descriptor
Used for commands that can read from stdin instead of a file
:stdin- STDOUT =
Standard output stream descriptor
Used for commands that can write to stdout instead of a file
:stdout- STDERR =
Standard error stream descriptor
Used for separating stderr from stdout
:stderr