Module: Ukiryu::Tools::ExecutableFinder
- Defined in:
- lib/ukiryu/tools/executable_finder.rb
Overview
Executable finder utilities for tool classes
This module provides methods to find executables on the system using aliases from tool definitions and system PATH.
Class Method Summary collapse
-
.find_executable(tool_name, tool_definition) ⇒ String?
Find the executable for a tool.
Class Method Details
.find_executable(tool_name, tool_definition) ⇒ String?
Find the executable for a tool
15 16 17 18 19 20 21 22 23 |
# File 'lib/ukiryu/tools/executable_finder.rb', line 15 def self.find_executable(tool_name, tool_definition) platform = Ukiryu::Runtime.instance.platform Ukiryu::ExecutableLocator.find( tool_name: tool_name, aliases: tool_definition.aliases || [], platform: platform ) end |